@@ -119,8 +119,7 @@ def _set_environment():
 
     if getattr(sys, 'frozen', False):  # pragma: no cover
         # Pyinstaller support
-        path = os.environ["PATH"]
-        if sys._MEIPASS in path:
+        if 'TESSDATA_PREFIX' in os.environ:
             # already changed
             return
 
@@ -128,15 +127,6 @@ def _set_environment():
         tessprefix = os.path.join(sys._MEIPASS, "data")
         logger.info("Running in packaged environment")
 
-        if not os.path.exists(os.path.join(tessprefix, "tessdata")):
-            logger.warning(
-                "Running from container, but no tessdata ({}) found !".format(
-                    tessprefix
-                )
-            )
-        else:
-            logger.info("TESSDATA_PREFIX set to [{}]".format(tessprefix))
-            os.environ['TESSDATA_PREFIX'] = tessprefix
         if not os.path.exists(tesspath):
             logger.warning(
                 "Running from container, but no tesseract ({}) found !".format(
@@ -149,6 +139,19 @@ def _set_environment():
                 tesspath + os.pathsep + os.environ['PATH']
             )
 
+        if not os.path.exists(os.path.join(tessprefix, "tessdata")):
+            logger.warning(
+                "Running from container, but no tessdata ({}) found !".format(
+                    tessprefix
+                )
+            )
+        else:
+            version = get_version(set_env=False)
+            if version[0] > 3:
+                tessprefix = os.path.join(tessprefix, "tessdata")
+            logger.info("TESSDATA_PREFIX set to [{}]".format(tessprefix))
+            os.environ['TESSDATA_PREFIX'] = tessprefix
+
 
 def can_detect_orientation():
     version = get_version()
@@ -413,7 +416,7 @@ def get_available_languages():
     return [lang for lang in langs if lang and lang[-1] != ':']
 
 
-def get_version():
+def get_version(set_env=True):
     """
     Returns Tesseract version.
 
@@ -428,15 +431,15 @@ def get_version():
     if g_version is not None:
         return g_version
 
-    _set_environment()
+    if set_env:
+        _set_environment()
 
     command = [TESSERACT_CMD, "-v"]
 
     proc = subprocess.Popen(command,
                             startupinfo=g_subprocess_startup_info,
                             creationflags=g_creation_flags,
-                            stdout=subprocess.PIPE,
-                            stderr=subprocess.STDOUT)
+                            stdout=subprocess.PIPE)
     ver_string = proc.stdout.read()
     ver_string = ver_string.decode('utf-8')
     ret = proc.wait()
